/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02258
 |         DRUG ABUSE TREATMENT OUTCOME STUDY (DATOS), 1991-1994:
 |                            [UNITED STATES]
 |         (DATASET 0009:  12-MONTH FOLLOW-UP URINE RESULT DATA)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02258-0009-statasetup.do)
 |
 **************************************************************************/

set mem 6m  /* Allocating 6 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Drug Abuse Treatment Outcome Study (DATOS), 1991-1994: [United States], Dataset 0009"

#delimit ;
label define AMPHET    -2 "INSUFF Q" -1 "NO DATA" 0 "NEGATIVE FOR DRUG"
                       1 "POSITIVE FOR DRUG" ;
label define BARBS     -2 "INSUFF Q" -1 "NO DATA" 0 "NEGATIVE FOR DRUG"
                       1 "POSITIVE FOR DRUG" ;
label define BENZO     -2 "INSUFF Q" -1 "NO DATA" 0 "NEGATIVE FOR DRUG"
                       1 "POSITIVE FOR DRUG" ;
label define CANNAB    -2 "INSUFF Q" -1 "NO DATA" 0 "NEGATIVE FOR DRUG"
                       1 "POSITIVE FOR DRUG" ;
label define COCAINE   -2 "INSUFF Q" -1 "NO DATA" 0 "NEGATIVE FOR DRUG"
                       1 "POSITIVE FOR DRUG" ;
label define METHAQ    -2 "INSUFF Q" -1 "NO DATA" 0 "NEGATIVE FOR DRUG"
                       1 "POSITIVE FOR DRUG" ;
label define OPIATES   -2 "INSUFF Q" -1 "NO DATA" 0 "NEGATIVE FOR DRUG"
                       1 "POSITIVE FOR DRUG" ;
label define PHENCY    -2 "INSUFF Q" -1 "NO DATA" 0 "NEGATIVE FOR DRUG"
                       1 "POSITIVE FOR DRUG" ;
label define USOURCE   1 "DATOS URINE FILE" 2 "CTOS URINE FILE/CROSSOVER" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CASEID = . if (CASEID <= -1 )
replace AMPHET = . if (AMPHET <= -1 )
replace BARBS = . if (BARBS <= -1 )
replace BENZO = . if (BENZO <= -1 )
replace CANNAB = . if (CANNAB <= -1 )
replace COCAINE = . if (COCAINE <= -1 )
replace METHAQ = . if (METHAQ <= -1 )
replace OPIATES = . if (OPIATES <= -1 )
replace PHENCY = . if (PHENCY <= -1 )
replace USOURCE = . if (USOURCE <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

